@@ -3,15 +3,14 @@
 from functools import partial
 from itertools import tee
 
-import numpy as np
-import pandas as pd
 import tensorflow as tf
 
 from .bert_preprocessing.create_bert_features import (
     create_bert_features_generator, create_multimodal_bert_features_generator)
 from .read_write_tfrecord import read_tfrecord, write_tfrecord
-from .special_tokens import EVAL, PREDICT, TRAIN
-from .utils import cluster_alphnum, infer_shape_and_type_from_dict, load_transformer_tokenizer
+from .special_tokens import PREDICT
+from .utils import (infer_shape_and_type_from_dict,
+                    load_transformer_tokenizer)
 
 
 def element_length_func(yield_dict):
@@ -96,7 +95,7 @@ def predict_input_fn(input_file_or_list, config, mode=PREDICT, labels_in_input=F
         first_element, _ = first_element
 
     tokenizer = load_transformer_tokenizer(
-        config.transformer_tokenizer_name)
+        config.transformer_tokenizer_name, config.transformer_tokenizer_loading)
     if isinstance(first_element, dict) and 'a' not in first_element:
         part_fn = partial(create_multimodal_bert_features_generator, problem='',
                           label_encoder=None,
