@@ -1,15 +1,11 @@
+
 import tensorflow as tf
-import os
 
 from . import modeling
 from .modeling import MultiModalBertModel
-
 from .optimizer import AdamWeightDecayOptimizer
-from .top import (
-    Seq2Seq, SequenceLabel, Classification,
-    MaskLM, PreTrain, MultiLabelClassification)
-from .experimental_top import (
-    LabelTransferHidden, GridTransformer, TaskTransformer)
+from .top import (Classification, MaskLM, MultiLabelClassification, PreTrain,
+                  Seq2Seq, SequenceLabel)
 
 
 def variable_summaries(var, name):
@@ -87,6 +83,8 @@ class BertMultiTask():
             use_one_hot_embeddings=config.use_one_hot_embeddings,
             features_dict=features)
         self.model = model
+        features['model_input_mask'] = self.model.get_input_mask()
+        features['model_token_type_ids'] = self.model.get_token_type_ids()
 
         feature_dict = {}
         for logit_type in ['seq', 'pooled', 'all', 'embed', 'embed_table']:
@@ -108,7 +106,7 @@ class BertMultiTask():
         # add summary
         if self.params.detail_log:
             with tf.compat.v1.name_scope('bert_feature_summary'):
-                for layer_ind, layer_output in enumerate(feature_dict['all']):
+                for _, layer_output in enumerate(feature_dict['all']):
                     variable_summaries(
                         layer_output, layer_output.name.replace(':0', ''))
 
@@ -163,19 +161,21 @@ class BertMultiTask():
         """
 
         if self.params.label_transfer:
-            ori_hidden_feature = {
-                'ori_'+k: v for k,
-                v in hidden_feature.items()}
-            label_transfer_layer = LabelTransferHidden(self.params)
-            hidden_feature = label_transfer_layer(
-                features, hidden_feature, mode)
-            hidden_feature.update(ori_hidden_feature)
+            raise NotImplementedError
+            # ori_hidden_feature = {
+            #     'ori_'+k: v for k,
+            #     v in hidden_feature.items()}
+            # label_transfer_layer = LabelTransferHidden(self.params)
+            # hidden_feature = label_transfer_layer(
+            #     features, hidden_feature, mode)
+            # hidden_feature.update(ori_hidden_feature)
 
         if self.params.task_transformer:
-            task_tranformer_layer = TaskTransformer(self.params)
-            task_tranformer_hidden_feature = task_tranformer_layer(
-                features, hidden_feature, mode)
-            self.params.hidden_dense = False
+            raise NotImplementedError
+            # task_tranformer_layer = TaskTransformer(self.params)
+            # task_tranformer_hidden_feature = task_tranformer_layer(
+            #     features, hidden_feature, mode)
+            # self.params.hidden_dense = False
 
         return_feature = {}
         return_hidden_feature = {}
@@ -200,14 +200,15 @@ class BertMultiTask():
                     )
 
                 if self.params.grid_transformer:
-                    with tf.compat.v1.variable_scope(top_scope_name):
-                        grid_layer = GridTransformer(self.params)
+                    raise NotImplementedError
+                    # with tf.compat.v1.variable_scope(top_scope_name):
+                    #     grid_layer = GridTransformer(self.params)
 
-                        hidden_feature_key = 'pooled' if problem_type == 'cls' else 'seq'
+                    #     hidden_feature_key = 'pooled' if problem_type == 'cls' else 'seq'
 
-                        hidden_feature_this_round[hidden_feature_key] = grid_layer(
-                            feature_this_round, hidden_feature_this_round, mode, problem)
-                    self.params.hidden_dense = False
+                    #     hidden_feature_this_round[hidden_feature_key] = grid_layer(
+                    #         feature_this_round, hidden_feature_this_round, mode, problem)
+                    # self.params.hidden_dense = False
                 return_hidden_feature[problem] = hidden_feature_this_round
                 return_feature[problem] = feature_this_round
         return return_feature, return_hidden_feature
@@ -257,8 +258,7 @@ class BertMultiTask():
 
                 with tf.compat.v1.variable_scope(top_scope_name, reuse=tf.compat.v1.AUTO_REUSE):
                     layer = problem_type_layer[
-                        problem_type](
-                        self.params)
+                        problem_type](self.params)
                     return_dict[problem] = layer(
                         feature_this_round,
                         hidden_feature_this_round, mode, problem)
@@ -341,7 +341,7 @@ class BertMultiTask():
 
         return optimizer
 
-    def create_train_spec(self, features, hidden_features, loss_eval_pred, mode, scaffold_fn):
+    def create_train_spec(self, loss_eval_pred, mode, scaffold_fn):
         optimizer = self.create_optimizer(
             self.params.lr,
             self.params.train_steps,
@@ -405,7 +405,7 @@ class BertMultiTask():
             scaffold=scaffold_fn)
         return output_spec
 
-    def create_spec(self, features, hidden_features, loss_eval_pred, mode, warm_start):
+    def create_spec(self, features, loss_eval_pred, mode, warm_start):
         """Function to create spec for different mode
 
         Arguments:
@@ -421,24 +421,33 @@ class BertMultiTask():
         tvars = tf.compat.v1.trainable_variables()
 
         if mode == tf.estimator.ModeKeys.TRAIN:
-
+            init_decoder = False
             if self.params.init_weight_from_huggingface:
                 # ckpt_path = os.path.join(self.params.transformer_model_name,
                 #                          'pretrained_model')
                 ckpt_path = self.params.transformer_model_name
-                (assignment_map, initialized_variable_names
-                 ) = modeling.get_assignment_map_from_keras_checkpoint(
-                    tvars, ckpt_path)
+                (assignment_map, _
+                 ) = modeling.get_assignment_map_from_keras_checkpoint(tvars, ckpt_path)
+
+                # init decoder weight
+                if self.params.transformer_decoder_model_name:
+                    (decoder_assignment_map, _
+                     ) = modeling.get_assignment_map_from_keras_checkpoint(tvars, self.params.transformer_decoder_model_name)
+                    init_decoder = True
+
             else:
                 ckpt_path = self.params.init_checkpoint
 
-                (assignment_map, initialized_variable_names
-                 ) = modeling.get_assignment_map_from_checkpoint(
-                    tvars, ckpt_path)
+                (assignment_map, _
+                 ) = modeling.get_assignment_map_from_checkpoint(tvars, ckpt_path)
 
             def scaffold():
                 init_op = tf.compat.v1.train.init_from_checkpoint(
                     ckpt_path, assignment_map)
+                if init_decoder:
+                    decoder_init_op = tf.compat.v1.train.init_from_checkpoint(
+                        self.params.transformer_decoder_model_name, decoder_assignment_map)
+                    init_op = tf.group(init_op, decoder_init_op)
                 return tf.compat.v1.train.Scaffold(init_op)
 
             if not warm_start:
@@ -449,16 +458,14 @@ class BertMultiTask():
                         'No variable initialized from pretrained checkpoint!')
                 train_scaffold = scaffold()
 
-            return self.create_train_spec(features,
-                                          hidden_features,
-                                          loss_eval_pred,
+            return self.create_train_spec(loss_eval_pred,
                                           mode,
                                           train_scaffold)
         elif mode == tf.estimator.ModeKeys.EVAL:
             eval_loss = {k: v[1] for k, v in loss_eval_pred.items()}
             total_eval_loss = 0
-            for k, v in eval_loss.items():
-                total_eval_loss += v
+            for _, var in eval_loss.items():
+                total_eval_loss += var
 
             eval_metric = {k: v[0] for k, v in loss_eval_pred.items()}
             total_eval_metric = {}
@@ -492,7 +499,7 @@ class BertMultiTask():
                 problem_sep_features, hidden_feature, mode)
 
             spec = self.create_spec(
-                features, hidden_feature, loss_eval_pred, mode, warm_start)
+                features, loss_eval_pred, mode, warm_start)
             return spec
 
         return model_fn
